.. {-{package_name}-} documentation master file, created by
   sphinx-quickstart on Thu Mar 23 15:36:13 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to {-{package_name}-}'s documentation!
==============================================

.. autosummary::
   :toctree: _autosummary

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
